@@ -21,6 +21,8 @@ import shutil
 import sys
 import tempfile
 
+import distro_info
+
 from breezy.branch import Branch
 from breezy.workingtree import WorkingTree
 import locale
@@ -41,13 +43,12 @@ import breezy.bzr  # noqa: E402
 
 from breezy.trace import note  # noqa: E402
 
-import distro_info
-
 from . import (  # noqa: E402
     NotDebianPackage,
     PendingChanges,
     available_lintian_fixers,
     find_fixers_dir,
+    get_committer,
     run_lintian_fixers,
     version_string,
     )
@@ -88,6 +89,10 @@ def main(argv=None):
             'Use features/compatibility levels that are not available in '
             'stable. (makes backporting harder)'),
         action='store_true', default=False)
+    parser.add_argument(
+        '--identity',
+        help='Print user identity that would be used when committing',
+        action='store_true', default=False)
     parser.add_argument(
         'fixers', metavar='FIXER', nargs='*',
         help='specific fixer to run')
@@ -128,6 +133,9 @@ def main(argv=None):
             note('Unable to open tree at %s: missing package %s',
                  args.directory, e.library)
             return 1
+        if args.identity:
+            print(get_committer(wt))
+            return 0
         since_revid = wt.last_revision()
         if args.fixers:
             fixers = [f for f in fixers if f.name in args.fixers]
